@@ -12,15 +12,15 @@ from lintian_brush.control import (
 
 # TODO(jelmer): Can we get these elsewhere rather than
 # hardcoding them here?
-minimum_debhelper_version = 9
+MINIMUM_DEBHELPER_VERSION = 9
 
 compat_release = os.environ.get('COMPAT_RELEASE', 'sid')
-if compat_release == 'sid':
-    new_debhelper_compat_version = 12
-elif compat_release == 'stretch':
-    new_debhelper_compat_version = 10
-else:
-    new_debhelper_compat_version = minimum_debhelper_version
+
+new_debhelper_compat_version = {
+    'sid': 12,
+    'buster': 12,
+    'stretch': 10,
+    }.get(compat_release, MINIMUM_DEBHELPER_VERSION)
 
 if os.path.exists('debian/compat'):
     # Package currently stores compat version in debian/compat..
@@ -97,7 +97,7 @@ else:
     update_control(source_package_cb=bump_debhelper_compat)
 
 
-if current_debhelper_compat_version < minimum_debhelper_version:
+if current_debhelper_compat_version < MINIMUM_DEBHELPER_VERSION:
     kind = "deprecated"
     tag = "package-uses-deprecated-debhelper-compat-version"
 else:
