@@ -106,6 +106,9 @@ def main(argv=None):
         '--trust',
         action='store_true',
         help=argparse.SUPPRESS)
+    parser.add_argument(
+        '--allow-reformatting', default=False, action='store_true',
+        help=argparse.SUPPRESS)
     parser.add_argument(
         'fixers', metavar='FIXER', nargs='*',
         help='specific fixer to run')
@@ -165,7 +168,8 @@ def main(argv=None):
                     compat_release=compat_release,
                     verbose=args.verbose,
                     minimum_certainty=args.minimum_certainty,
-                    trust_package=args.trust)
+                    trust_package=args.trust,
+                    allow_reformatting=args.allow_reformatting)
             except NotDebianPackage:
                 note("%s: Not a debian package.", wt.basedir)
                 return 1
