@@ -86,7 +86,7 @@ Lintian-Tags: i-fix-another-tag, no-extension
 class DummyFixer(Fixer):
 
     def run(self, basedir, current_version, compat_release, minimum_certainty,
-            trust_package):
+            trust_package, allow_reformatting):
         with open(os.path.join(basedir, 'debian/control'), 'a') as f:
             f.write('a new line\n')
         return FixerResult("Fixed some tag.\nExtended description.",
@@ -96,7 +96,7 @@ class DummyFixer(Fixer):
 class FailingFixer(Fixer):
 
     def run(self, basedir, current_version, compat_release, minimum_certainty,
-            trust_package):
+            trust_package, allow_reformatting):
         with open(os.path.join(basedir, 'debian/foo'), 'w') as f:
             f.write("blah")
         with open(os.path.join(basedir, 'debian/control'), 'a') as f:
@@ -220,7 +220,7 @@ Arch: all
 
         class UncertainFixer(Fixer):
             def run(self, basedir, current_version, compat_release,
-                    minimum_certainty, trust_package):
+                    minimum_certainty, trust_package, allow_reformatting):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Renamed a file.", certainty='possible')
@@ -236,7 +236,7 @@ Arch: all
 
         class UncertainFixer(Fixer):
             def run(self, basedir, current_version, compat_release,
-                    minimum_certainty, trust_package):
+                    minimum_certainty, trust_package, allow_reformatting):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Renamed a file.", certainty='possible')
@@ -251,7 +251,7 @@ Arch: all
 
         class NewFileFixer(Fixer):
             def run(self, basedir, current_version, compat_release,
-                    minimum_certainty, trust_package):
+                    minimum_certainty, trust_package, allow_reformatting):
                 with open(os.path.join(basedir, 'debian/somefile'), 'w') as f:
                     f.write("test")
                 return FixerResult("Created new file.", ['some-tag'])
@@ -282,7 +282,7 @@ Arch: all
 
         class RenameFileFixer(Fixer):
             def run(self, basedir, current_version, compat_release,
-                    minimum_certainty, trust_package):
+                    minimum_certainty, trust_package, allow_reformatting):
                 os.rename(os.path.join(basedir, 'debian/control'),
                           os.path.join(basedir, 'debian/control.blah'))
                 return FixerResult("Renamed a file.")
@@ -311,7 +311,7 @@ Arch: all
 
         class EmptyFixer(Fixer):
             def run(self, basedir, current_version, compat_release,
-                    minimum_certainty, trust_package):
+                    minimum_certainty, trust_package, allow_reformatting):
                 return FixerResult("I didn't actually change anything.")
         with tree.lock_write():
             self.assertRaises(
